/**
    This file is part of Sudoku United.

    Sudoku United is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Sudoku United is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Sudoku United.  If not, see <http://www.gnu.org/licenses/>.
*/

import QtQuick 1.1
import com.nokia.symbian 1.1
import "UIConstantsSymbian.js" as UIConstantsSymbian


Rectangle {
    id: loadingDialog

    anchors.fill: parent
    color: "#DD000000"
    visible: false

    /**
      * The text to show to the user while loading is in progress.
      */
    property string text: "Loading"

    /**
      * Shows a cancel button enabling the user to cancel the action.
      */
    property bool showCancelButton: false

    /**
      * This signal is emitted after the dialog has been closed.
      */
    signal closed()
    signal rejected()

    function isVisible() {
        return loadingDialog.visible
    }

    function close() {
        loadingDialog.visible = false
    }

    function forceClose() {
        if (loadingDialog.visible == true) {
            _shouldClose = true;
            return;
        }

        loadingDialog.visible = false;
    }
    function open() {
        loadingDialog.visible = true
    }

    Column {
        anchors.centerIn: parent
        spacing: 16

        BusyIndicator {
            id: busyIndicator
            running: true
            height: UIConstantsSymbian.BUSY_INDICATOR_LARGE
            width: UIConstantsSymbian.BUSY_INDICATOR_LARGE
            platformInverted: true
            anchors.horizontalCenter: parent.horizontalCenter
        }

        Label {
            color: "white"
            text: loadingDialog.text
            platformInverted: true
            anchors.horizontalCenter: parent.horizontalCenter
        }

        Button {
            visible: loadingDialog.showCancelButton
            text: "Cancel"
            platformInverted: true
            anchors.horizontalCenter: parent.horizontalCenter

            onClicked: rejected()
        }
    }

    property bool _shouldClose : false;

    Component.onCompleted: {
        if (_shouldClose) {
            _shouldClose = false;
            loadingDialog.visible = false;
        } else if (loadingDialog.visible == false)
            closed()
    }
}
