/**
    This file is part of Sudoku United.

    Sudoku United is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Sudoku United is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Sudoku United.  If not, see <http://www.gnu.org/licenses/>.
*/

import QtQuick 1.1
import sudoku 1.0
import "../../gameview"

Rectangle{
    property GameBoard gameBoard

    property Cell cell
    property string mode: noteEditMode.checked ? "note" : "normal"

    id: chooser
    width: 280
    height: 170
    color: "#AF222222"
    radius: 7

    Connections {
        target: gameBoard

        onCellClicked: {
            chooser.cell = cell
        }
    }

    function setNumber(cell, number) {
        //find collisions
        var collisions = gameBoard.board.isValidMove(cell.x, cell.y, number);

        if (collisions.length === 0) {
            if (cell.value != number) {
                cell.valueOwner = localPlayer
                cell.value = number
            }
        } else {
            // Find colliding cells
            collisions.forEach(function (cell) {
                                   gameBoard.cellAt(cell.x, cell.y).collision = true
                               });
        }
    }

    Rectangle {
        id: numberBoard
        width: 250
        height: 100

        //property variant cell

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 10
        border.width: 2;
        radius: 0
        border.color: "grey"

        Grid {
            id: numberGrid
            columns: 5
            rows:  2
            anchors.fill: parent

            Component.onCompleted: {
                //create one ImageCell with value 0 (erase value)
                var component = Qt.createComponent("ImageCell.qml");
                var object = component.createObject(numberGrid, { "number": 0,
                                                        "numberChooser": function () { return chooser; } })
                object.selected.connect(updateValue)

                //create NumberCells
                component = Qt.createComponent("NumberCell.qml");
                for (var i = 1; i <= 9; i++) {
                    object = component.createObject(numberGrid, { "number": i,
                                                            "numberChooser": function () { return chooser; } })
                    object.selected.connect(updateValue)
                }
            }

            function updateValue(number) {
                if ( chooser.mode == "note" ){
                    if (number == 0){
                        for (var i = 0; i < 9; i++){
                            cell.noteModel.get(i).modelMarked = false
                        }
                    } else {
                        cell.noteModel.get(number - 1).modelMarked = !cell.noteModel.get(number - 1).modelMarked
                    }
                    return;
                } else {
                    // symbian fix: setNumber checks for collisions and always collides with zero
                    if (number == 0){
                        cell.value = 0
                    } else {
                        setNumber(cell, number)
                    }
                }
            }

        }
    }

    Button {
        anchors { topMargin: 8; top:numberBoard.bottom; left: numberBoard.left }
        width: numberBoard.width/3
        iconSource: "qrc:/edit_symbian.png"
        id: noteEditMode
        checkable: true
    }
    GameTimer {
        board: gameBoard.board
        anchors { topMargin: 8; top:numberBoard.bottom; right: numberBoard.right }
        width: numberBoard.width/3
    }


}
